"""
__version__.py
~~~~~~~~~~~~~~

Information about the current version of the super_resolution package.
"""

__title__ = 'super_resolution'
__description__ = 'Library generating 4x/8x super resoltion using deep convolutional neural networks.'
__version__ = '0.2.1'
__author__ = 'Feng Wang'
__author_email__ = 'wang_feng@live.com'
__license__ = 'BSD'
__url__ = 'https://github.com/fengwang/super_resolution'

